=== modified file 'privacy_policy/admin.py'
--- privacy_policy/admin.py	2018-10-02 16:55:42 +0000
+++ privacy_policy/admin.py	2018-10-08 17:51:36 +0000
@@ -6,6 +6,7 @@
 
 
 class PrivacyPolicyAdmin(admin.ModelAdmin):
+    prepopulated_fields = {"slug": ("language",)}
     list_display = ('language',)
 
 

=== modified file 'privacy_policy/migrations/0001_initial.py'
--- privacy_policy/migrations/0001_initial.py	2018-10-02 16:55:42 +0000
+++ privacy_policy/migrations/0001_initial.py	2018-10-08 17:51:36 +0000
@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Generated by Django 1.11.12 on 2018-10-02 18:48
+# Generated by Django 1.11.12 on 2018-10-08 18:23
 from __future__ import unicode_literals
 
 from django.db import migrations, models
@@ -19,6 +19,7 @@
                 ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                 ('language', models.CharField(default='English', help_text='Will be displayed as a level 1 header', max_length=30, unique=True)),
                 ('policy_text', models.TextField(help_text='Text will be rendered using markdown syntax')),
+                ('slug', models.SlugField(unique=True)),
             ],
             options={
                 'ordering': ['language'],

=== modified file 'privacy_policy/models.py'
--- privacy_policy/models.py	2018-10-05 19:10:18 +0000
+++ privacy_policy/models.py	2018-10-08 17:51:36 +0000
@@ -12,9 +12,13 @@
                                 unique=True)
     policy_text = models.TextField(
         help_text='Text will be rendered using markdown syntax')
+    slug = models.SlugField(unique=True)
 
     class Meta:
         ordering = ['language']
 
+    def __unicode__(self):
+        return self.language
+    
     def get_absolute_url(self):
         return reverse('policy_translated', kwargs={'lang': self.language})
\ No newline at end of file

=== modified file 'privacy_policy/urls.py'
--- privacy_policy/urls.py	2018-10-05 19:10:18 +0000
+++ privacy_policy/urls.py	2018-10-08 17:51:36 +0000
@@ -3,5 +3,5 @@
 
 urlpatterns = [
     url(r'^$', views.privacy_policy, name='privacy_policy'),
-    url(r'^(?P<lang>[-\w]+)/', views.privacy_policy, name='policy_translated'),
+    url(r'^(?P<slug>[-\w]+)/', views.privacy_policy, name='policy_translated'),
 ]

=== modified file 'privacy_policy/views.py'
--- privacy_policy/views.py	2018-10-06 07:16:37 +0000
+++ privacy_policy/views.py	2018-10-08 17:51:36 +0000
@@ -2,38 +2,44 @@
 from __future__ import unicode_literals
 
 from django.shortcuts import render
+from django.core.exceptions import ObjectDoesNotExist
+
 from privacy_policy.models import PrivacyPolicy
-from django.core.exceptions import ObjectDoesNotExist
 
 
 def _format_text(language, text):
     return '[TOC]\n\n#{}\n{}'.format(language, text)
-    
-    
+
+
 def privacy_policy(request, *args, **kwargs):
-    """Creates the text of a policy and prepare it for markdown."""
-
-    # Defaults to 'English'
-    lang = kwargs.pop('lang', 'English')
+    """Creates the text of a policy and prepare it for markdown.
+
+    We handle here also a link with no slug (/privacy). In this case try
+    to load english, else load the first entry in the DB.
+    """
+
+    # Default is 'english'
+    slug = kwargs.pop('slug', 'english')
     policies = PrivacyPolicy.objects.all()
 
-    try:
-        policy = policies.get(language=lang)
-    except ObjectDoesNotExist:
-        # Lets try to find a valid policy
+    if policies.count():
         try:
+            policy = policies.get(slug=slug)
+        except ObjectDoesNotExist:
             policy = policies.all()[0]
-        except IndexError:
-            policy = None
-            text = 'No Policy created yet!'
-            languages = ''
+            slug = policy.slug
 
-    if policy:
         text = _format_text(policy.language, policy.policy_text)
-        languages = [x.language for x in policies.exclude(language=lang)]
-        
+        languages = [(x.language, x.slug) for x in policies.exclude(slug=slug)]
+        current_lang = policy.language
+    else:
+        text = 'No Policy created yet!'
+        languages = ''
+        current_lang = ''
+
     context = {
         'text': text,
         'languages': languages,
+        'cur_lang': current_lang,
     }
     return render(request, 'privacy_policy.html', context)

=== modified file 'templates/footer.html'
--- templates/footer.html	2018-10-05 19:10:18 +0000
+++ templates/footer.html	2018-10-08 17:51:36 +0000
@@ -8,6 +8,7 @@
 
 <div id="footer">
 	Copyright &copy; 2009 - {% current_year %} By the Widelands Development Team<br />
-	<a class="small" href="{% url 'legal_notice' %}">Legal notice (contact)</a> -
+	<a class="small" href="{% url 'legal_notice' %}">Legal notice (contact)</a>
+	 <span class="small"> &#9679; </span>
 	<a class="small" href="{% url 'privacy_policy'%}">Privacy Policy</a>
 </div>

=== modified file 'templates/privacy_policy.html'
--- templates/privacy_policy.html	2018-10-05 19:10:18 +0000
+++ templates/privacy_policy.html	2018-10-08 17:51:36 +0000
@@ -1,7 +1,7 @@
 {% extends "base.html" %}
 {% load wl_markdown %}
 
-{% block title %}Privacy policy{{ block.super }}{% endblock %}
+{% block title %}Privacy policy {{ cur_lang }} {{ block.super }}{% endblock %}
 
 {% block extra_head %}
 {{ block.super}}
@@ -12,14 +12,18 @@
 <h1>Privacy Policy</h1>
 
 <div class="blogEntry">
-    {% if languages.length > 1 %}
+    {% with languages|length as count %}
+    {% if count > 0 %}
     <p>
         This site is also available in:
-        {% for lang in languages %}
-                <a href="{% url 'policy_translated' lang %}">{{ lang }}</a>
+        {% for lang, slug in languages %}
+            {# The if statement has to be directly after the link, otherwise we have unwanted spaces #}
+            <a href="{% url 'policy_translated' slug %}">{{ lang }}</a>{% if count > 1  and forloop.revcounter0 == 1 %} and
+        {% elif count > 1  and forloop.revcounter0 != 0 %}, {% endif %}
         {% endfor %}
     </p>
     {% endif %}
+    {% endwith %}
     
     {{ text|wl_markdown }}
 </div>

